# vim: set ts=4 sw=4 et:

# Copyright (c) 2012 Raymond Wooninck <tittiatcoke@gmail.com>
# Copyright (c) 2010-2012 Pascal Bleser <pascal.bleser@opensuse.org>
# Copyright (c) 2010 oc2pus <toni@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments to packman@links2linux.de

%{!?python_sitelib:  %global python_sitelib  %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}

Summary:        Video Editor
Name:           openshot
Version:        1.4.3
Release:        1.12
Group:          Productivity/Multimedia/Video/Editors and Convertors
License:        GPL-2.0+
URL:            http://www.openshotvideo.com/
Source:         http://launchpad.net/openshot/1.4/%{version}/+download/openshot-%{version}.tar.gz
Source90:       %{name}-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root
%if %suse_version > 1110
BuildArch:      noarch
%endif
%py_requires
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python-devel
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
Requires(pre):  shared-mime-info
%if %suse_version >= 1110
Requires:       python-base >= %{py_ver}
%else
Requires:       python >= %{py_ver}
%endif
Requires:       python-gtk
Requires:       python-goocanvas
Requires:       python-mlt
Requires:       python-xdg
Requires:       python-imaging
Requires:       frei0r-plugins
Requires:       python-httplib2
# It segfaults if the avformat plugin is not available
# We don't actually need a specific ABI version. But since we need a python-mlt
# package that matches the libmltX-modules with the avformat plugin we do this
%define mlt_soname %(rpm -q --provides python-mlt | grep 'python-mlt[0-9]\\+' | sed 's/python-mlt\\([0-9]\\+\\)[[:space:]]*/\\1/')
Requires:       mlt(%{mlt_soname})(avformat)
Requires:       python-mlt%{mlt_soname}
# Keep track of Requires as BuildRequires as well, to fail the build
# if something is missing:
BuildRequires:  python-gtk
BuildRequires:  python-goocanvas
BuildRequires:  python-mlt
BuildRequires:  python-pyxdg
BuildRequires:  frei0r-plugins
BuildRequires:  python-httplib2
BuildRequires:  python-imaging

%description
OpenShot Video Editor is a program that creates, modifies, and edits
video files.

%prep
%setup -q -n %{name}-%{version}
find . -type f -name '*.py' -exec %__perl -n -i -e 'print $_ unless ($.==1 and /^#!/)' {} \;

%build
%__python setup.py build

%install
%__python setup.py install \
    --root="%{buildroot}" \
    --prefix="%{_prefix}" \
    --record-rpm=files.lst

%__perl -n -i -e 'print unless m|^(%dir\s+)?%{_mandir}|' files.lst

%__perl -n -i -e 'print unless m,^(%dir\s+)?(/usr/lib|/usr/lib/mime|/usr/share/applications|/usr/share/pixmaps|/usr/share/mime|/usr/share/mime/packages)/?$,' files.lst

%__perl -n -i -e 'print unless m|^(%dir\s+)?%{python_sitelib}/openshot/locale|' files.lst

# craptastic spaces...
%__perl -n -i -e 'print unless m/(Color\sMap.jpg$|Night\sLights.jpg$|Spec\sMask.jpg$)/' files.lst

L="$PWD/files.lst"
pushd "%{buildroot}%{python_sitelib}/openshot/locale"
    /bin/ls -1 | while read d; do
        [ -d "$d" ] || continue
        echo "%lang($d) %{python_sitelib}/openshot/locale/$d" >>"$L"
    done
popd

%__install -Dm 644 \
    openshot/themes/tango/icons/openshot.png \
    %{buildroot}%{_datadir}/pixmaps/openshot.png

%suse_update_desktop_file -i %{name} AudioVideo AudioVideoEditing

%__rm -r "%{buildroot}/usr/lib/mime/packages"
%__perl -n -i -e 'print unless m|^(%dir\s+)?/usr/lib/mime/packages|' files.lst

%fdupes -s "%{buildroot}%{python_sitelib}/openshot/themes"

%__ln_s openshot "%{buildroot}%{_bindir}/OpenShot"

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%post
%{_bindir}/update-mime-database %{_datadir}/mime >/dev/null

%postun
%{_bindir}/update-mime-database %{_datadir}/mime >/dev/null

%files -f files.lst
%defattr(-,root,root,-)
%doc AUTHORS COPYING README
%doc %{_mandir}/man1/%{name}*%{ext_man}
%dir %{python_sitelib}/openshot/locale
%dir %{python_sitelib}/openshot/blender
%dir %{python_sitelib}/openshot/blender/earth
%{python_sitelib}/openshot/locale/README
# craptastic space fixup
%{python_sitelib}/openshot/blender/earth/*.jpg

%{_datadir}/pixmaps/openshot.png
%{_bindir}/OpenShot

%changelog
* Tue Sep 10 2013 boris@steki.net
- updated to latest upstream 1.4.3
  * OpenShot 1.4.3 is a major upstream release,
    which address many critical bugs, adds some highly requested
    features (such as adding effects to multiple clips,
    timeline improvements, new 3D animations, etc...),
    and is now optimized for dark GTK+ themes.
  * bugfix information can be found at:
    https://launchpad.net/openshot/1.4/1.4.3/
* Sun Apr 22 2012 pascal.bleser@opensuse.org
- update to 1.4.2 (no upstream changelog information available)
* Wed Oct 19 2011 tittiatcoke@gmail.com
- Update to 1.4.0
* Fri Apr  1 2011 pascal.bleser@opensuse.org
- fix: add missing requirement python-imaging
* Tue Mar  8 2011 pascal.bleser@opensuse.org
- fix usage by adding Requires:python-httplib2, thanks to Malcolm Lewis
* Mon Mar  7 2011 pascal.bleser@opensuse.org
- fix typo for frei0r-plugins dependency
* Sun Mar  6 2011 pascal.bleser@opensuse.org
- add frei0r-plugins to Requires
- add a symlink "OpenShot" in /usr/bin
* Wed Mar  2 2011 pascal.bleser@opensuse.org
- update to 1.3.0
* Sat Nov 13 2010 pascal.bleser@opensuse.org
- update to 1.2.2
* Fri Apr 30 2010 toni@links2linux.de
- update to 1.1.3
* Mon Mar  8 2010 toni@links2linux.de
- update to 1.1.0
* Tue Jan 12 2010 toni@links2linux.de
- Initial build 1.0.0
